==> custom_pages-v1.12.9.zip: custom_pages/messages/ca/base.php <==
<?php

return [
    '<strong>Custom</strong> Pages' => 'Pàgines <strong>personalitzades</strong>',
    'Add' => 'Afegeix',
    'Add a file icon before the title' => 'Afegeix una icona de fitxer abans del títol',
    'Advanced' => 'Avançat',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permet afegir pàgines (Markdown, iframe o enllaços) a la navegació de l’espai',
    'Allows you to add content in MarkDown syntax.' => 'Us permet afegir contingut en sintaxi Markdown.',
    'Alternate text' => 'Text alternatiu',
    'Always' => 'Sempre',
    'Back' => 'Enrere',
    'Back to dashboard' => 'Torna a la portada',
    'Back to overview' => 'Tornar a la vista general',
    'Back to space' => 'Torna a l’espai',
    'Category' => 'Categoria',
    'Configuration' => 'Configuració',
    'Content' => 'Contingut',
    'Create' => 'Crea',
    'Css Class' => 'Classe CSS',
    'Custom Pages' => 'Pàgines personalitzades',
    'Custom pages' => 'Pàgines personalitzades',
    'Dashboard' => 'Inici',
    'Default' => 'Per defecte',
    'Default Content' => 'Contingut per defecte',
    'Delete' => 'Suprimeix',
    'Edit' => 'Edita',
    'Edit Page' => 'Edita la pàgina',
    'Empty' => 'Buida',
    'File' => 'Fitxer',
    'General' => 'General',
    'Html' => 'Html',
    'ID' => 'ID',
    'Iframe' => 'Iframe',
    'Insert' => 'Inserir',
    'Link' => 'Enllaç',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Navegació',
    'Overview' => 'Resum',
    'PHP' => 'PHP',
    'Pages' => 'Pàgines',
    'Public' => 'Públic',
    'Reset' => 'Reinicialitza',
    'Settings' => 'Configuració',
    'Show additional file information (size)' => 'Mostra informació addicional del fitxer (mida)',
    'Sort Order' => 'Ordre de classificació',
    'Source' => 'Font',
    'Space' => 'Espai',
    'Spaces' => 'Espais',
    'Stream' => 'Activitat',
    'Style' => 'Estil',
    'Submit' => 'Envia',
    'Template' => 'Plantilla',
    'Templates' => 'Plantilles',
    'Title' => 'Títol',
    'Top Navigation' => 'Barra de navegació',
    'Topics' => 'Temes',
    'Type' => 'Tipus',
    'User Account Menu (Settings)' => 'Menu del compte d\'usuari (Configuració)',
    'Visibility' => 'Visibilitat',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Edit</strong> snippet' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Custom' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Icon' => '',
    'Import' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Upload image' => '',
    'Usage' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/ca/base.php <==
<?php

return [
    '<strong>Custom</strong> Pages' => 'Pàgines <strong>personalitzades</strong>',
    'Add' => 'Afegeix',
    'Add a file icon before the title' => 'Afegeix una icona de fitxer abans del títol',
    'Advanced' => 'Avançat',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permet afegir pàgines (Markdown, iframe o enllaços) a la navegació de l’espai',
    'Allows you to add content in MarkDown syntax.' => 'Us permet afegir contingut en sintaxi Markdown.',
    'Alternate text' => 'Text alternatiu',
    'Always' => 'Sempre',
    'Back' => 'Enrere',
    'Back to dashboard' => 'Torna a la portada',
    'Back to overview' => 'Tornar a la vista general',
    'Back to space' => 'Torna a l’espai',
    'Category' => 'Categoria',
    'Configuration' => 'Configuració',
    'Content' => 'Contingut',
    'Create' => 'Crea',
    'Css Class' => 'Classe CSS',
    'Custom Pages' => 'Pàgines personalitzades',
    'Custom pages' => 'Pàgines personalitzades',
    'Dashboard' => 'Inici',
    'Default' => 'Per defecte',
    'Default Content' => 'Contingut per defecte',
    'Delete' => 'Suprimeix',
    'Edit' => 'Edita',
    'Edit Page' => 'Edita la pàgina',
    'Empty' => 'Buida',
    'File' => 'Fitxer',
    'General' => 'General',
    'Html' => 'Html',
    'ID' => 'ID',
    'Iframe' => 'Iframe',
    'Insert' => 'Inserir',
    'Link' => 'Enllaç',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Navegació',
    'Overview' => 'Resum',
    'PHP' => 'PHP',
    'Pages' => 'Pàgines',
    'Public' => 'Públic',
    'Reset' => 'Reinicialitza',
    'Settings' => 'Configuració',
    'Show additional file information (size)' => 'Mostra informació addicional del fitxer (mida)',
    'Sort Order' => 'Ordre de classificació',
    'Source' => 'Font',
    'Space' => 'Espai',
    'Spaces' => 'Espais',
    'Stream' => 'Activitat',
    'Style' => 'Estil',
    'Submit' => 'Envia',
    'Template' => 'Plantilla',
    'Templates' => 'Plantilles',
    'Title' => 'Títol',
    'Top Navigation' => 'Barra de navegació',
    'Topics' => 'Temes',
    'Type' => 'Tipus',
    'User Account Menu (Settings)' => 'Menu del compte d\'usuari (Configuració)',
    'Visibility' => 'Visibilitat',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Edit</strong> snippet' => '',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Custom' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Icon' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Sorting' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Upload image' => '',
    'Usage' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
